@@ -19,28 +19,24 @@ stopifnot(all.equal(s2[,"(Intercept)"], -s2[,"int"]))
 
 ### log_first for count data (by Sandra Siegfried)
 ### use: y + 1; log_first = TRUE, support = c(1, ...), bounds = c(1, ...)
-library("MASS")
 set.seed(29)
+
 Nsim <- 100
-b1 <- - 4.5
+n <- 4000
+b1 <- -4.5
 b0 <- 5
 theta <- 2
+
 h <- qlogis(ppois(0:100, lambda = 5))
-dgp <- function(n = 4000){
-  x <- runif(n, min = 0, max = 1) 
-  log.mu <- b0 + b1 * x
-  h.m <- matrix(h, nrow = length(h), ncol = length(x)) 
-  p <- (plogis(t(h.m) - b1 * x) - runif(n))^2
-  y <- max.col(-p) - 1
-  m <- Colr(y ~ x, data = data.frame(y = y, x = x), 
-            bounds = c(0L, Inf), fixed = c("x" = -b1),
-            support = c(0L, floor(quantile(y, .9))), order = 10)
-  
-  ret <- data.frame(x = x, y = as.integer(y))
-  attr(ret, "mC") <- m
-  ret
-}
-d <- dgp()
+
+x <- runif(n, min = 0, max = 1) 
+log.mu <- b0 + b1 * x
+
+h.m <- matrix(h, nrow = length(h), ncol = length(x)) 
+p <- (plogis(t(h.m) - b1 * x) - runif(n))^2
+y <- max.col(-p) - 1
+
+d <- data.frame(x = x, y = as.integer(y))
 d$y.p1 <- d$y + 1L
 
 m1 <- Colr(y ~ x, data = d,
